==> qunit-2.17.2.tgz: package/README.md <==
<p align="center"><img src="/docs/img/logo-with-colored-dark-text.svg" height="width" height="125" alt="QUnit"></p>

<div align="center">

[![Build Status](https://github.com/qunitjs/qunit/actions/workflows/CI.yaml/badge.svg)](https://github.com/qunitjs/qunit/actions/workflows/CI.yaml)
[![Test Coverage](https://coveralls.io/repos/qunitjs/qunit/badge.svg)](https://coveralls.io/github/qunitjs/qunit)
[![Chat on Gitter](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/qunitjs/qunit?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![npm](https://img.shields.io/npm/v/qunit.svg?style=flat)](https://www.npmjs.com/package/qunit)
[![Reproducible Builds](https://img.shields.io/badge/Reproducible_Builds-ok-success?labelColor=1e5b96)](https://reproducible-builds.org/)

</div>

**QUnit** is a powerful, easy-to-use JavaScript testing framework. It was originally developed for the jQuery
project and has since evolved to test any client-side or server-side JavaScript code. QUnit has no dependencies and supports Node.js, SpiderMonkey, and all major web browsers.

## Documentation

* [API documentation](https://api.qunitjs.com/)
* [Guides how-to](https://qunitjs.com/guides/)
* [Browser support](https://qunitjs.com/intro/#browser-support)
* [Integrations](https://qunitjs.com/intro/#integrations)

## Support

To report a bug or request a new feature, [open an issue](https://github.com/qunitjs/qunit/issues).

If you need help using QUnit, chat with us on [Gitter](https://gitter.im/qunitjs/qunit).

## Contribute

If you are interested in helping develop QUnit, check out our [contributing guide](./CONTRIBUTING.md).

==> qunit-2.19.4.tgz: package/README.md <==
<p align="center"><img src="/docs/img/logo-with-colored-dark-text.svg" height="width" height="125" alt="QUnit"></p>

<div align="center">

[![Continuous integration](https://github.com/qunitjs/qunit/actions/workflows/CI.yaml/badge.svg)](https://github.com/qunitjs/qunit/actions/workflows/CI.yaml)
[![Test coverage](https://coveralls.io/repos/qunitjs/qunit/badge.svg)](https://coveralls.io/github/qunitjs/qunit)
[![Chat on Gitter](https://badges.gitter.im/Join%20Chat.svg)](https://gitter.im/qunitjs/qunit?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
[![npm](https://img.shields.io/npm/v/qunit.svg?style=flat)](https://www.npmjs.com/package/qunit)
[![Reproducible build status](https://img.shields.io/badge/Reproducible_Builds-ok-success?labelColor=1e5b96)](https://github.com/qunitjs/qunit/actions/workflows/reproducible.yaml)

</div>

**QUnit** is a powerful, easy-to-use JavaScript testing framework. It was originally developed for the jQuery
project and has since evolved to test any client-side or server-side JavaScript code. QUnit has no dependencies and supports Node.js, SpiderMonkey, and all major web browsers.

## Documentation

* [API documentation](https://api.qunitjs.com/)
* [Guides how-to](https://qunitjs.com/guides/)
* [Browser support](https://qunitjs.com/intro/#browser-support)
* [Integrations](https://qunitjs.com/intro/#integrations)

## Support

To report a bug or request a new feature, [open an issue](https://github.com/qunitjs/qunit/issues).

If you need help using QUnit, chat with us on [Gitter](https://gitter.im/qunitjs/qunit).

## Contribute

If you are interested in helping develop QUnit, check out our [contributing guide](./CONTRIBUTING.md).
